#!/bin/sh
# Copyright (C) 2000-2020 Remote.it All rights reserved.

REMOTEIT_DIR="/var/packages/Remoteit/target/app"

. $REMOTEIT_DIR/oem.sh

INSTALL_API=https://install.remote.it/v1
VERSION=$(cat $REMOTEIT_DIR/version.txt)
ARCH_FAMILY=$(cat $REMOTEIT_DIR/arch_family)
ARCH_DIR=$REMOTEIT_DIR/arch/$ARCH_FAMILY


r3_update_config() {
  echo "Updating remote.it configuration."

  local config

  if [ -f $REMOTEIT_DIR/config.json ]; then
    config=$(cat $REMOTEIT_DIR/config.json)

  elif [ -n "$license_key" ]; then

    local registration=$license_key

    [ -n "$registration" ] || return 0

    config=$($ARCH_DIR/jq -n --arg registration "$registration" '{$registration}')  
  else
    config='{}'
  fi


  $ARCH_DIR/jq -n \
  --argjson config "$config" \
  --arg name "$(r3_get_name)" \
  --arg identity "$(r3_get_identity)" \
  --argjson manufacturer "$(r3_get_manufacturer)" \
  --argjson platform "$(r3_get_platform)" \
  --argjson metadata "$(r3_get_metadata)" \
  '$config * {$name, $identity, $manufacturer, $platform, $metadata}' | curl -sfo $REMOTEIT_DIR/config.json -d @- $INSTALL_API/refresh

}

r3_get_config() {
  [ -r $REMOTEIT_DIR/config.json ] || exit 0
  config=$($ARCH_DIR/jq -r --arg id "$1" '.device,.services[] | select(.id==$id) | .config' "$REMOTEIT_DIR/config.json")
  echo $config
}

r3_get_claim() {
  local claim

  [ -r $REMOTEIT_DIR/config.json ] && claim=$($ARCH_DIR/jq -er '.device.claim' "$REMOTEIT_DIR/config.json") && echo "$claim"
}

r3_install_agent() {
  echo "Installing remote.it agent."

  r3_update_config
  chmod 777 $REMOTEIT_DIR/config.json

  local code=$(r3_get_claim)


  if [ -n "$license_key" ]; then
    local deviceName=$(r3_get_name)
    /usr/syno/bin/synodsmnotify -c com.Remoteit @administrators Remoteit:app_tree:index_title Remoteit:app_tree:register_license $deviceName
  elif [ -n "$code" ]; then
    echo
    echo "--------------------- Claim this device ---------------------"
    echo
    echo "Use the code $code to register this device to your account"
    echo
    echo "--------------------- Claim this device ---------------------"
    echo
    
    /usr/syno/bin/synodsmnotify -c com.Remoteit @administrators Remoteit:app_tree:index_title Remoteit:app_tree:register_code $code
  else
       echo 'No code was generated'
  fi
}