#!/bin/sh

REMOTEIT_DIR="/var/packages/Remoteit/target/app"
METADATA_URL=http://169.254.169.254/latest/meta-data
ARCH_FAMILY=$(cat $REMOTEIT_DIR/arch_family)
ARCH_DIR=$REMOTEIT_DIR/arch/$ARCH_FAMILY

r3_logger() {
  logger -t remoteit "$@"
}

r3_get_architecture() {
  arch
}

r3_is_ec2() {
  curl -s -f -m 1 $METADATA_URL > /dev/null
  echo $?
}

isEc2=$(r3_is_ec2)

r3_get_name() {
  if [ "$isEc2" -eq 0 ]; then
  curl -s $METADATA_URL/instance-id | sed -e 's/-//g'
  else
  cat /proc/sys/kernel/hostname
  fi
}

r3_get_macaddr() {
  if [ "$isEc2" -eq 0 ]; then
  curl -s $METADATA_URL/mac
  else
  ip link show up | grep ether | head -n 1 | awk '{print $2}'
  fi
}


r3_get_identity() {
  r3_get_macaddr
}

r3_get_manufacturer() {
  echo 34304
}

r3_get_platform() {
  echo 1210
}

r3_get_metadata() {

  $ARCH_DIR/jq -n \
  --arg version "$VERSION" \
  --arg installDir "/usr/local/bin/app" \
  --arg macAddress "$(r3_get_macaddr)" \
  '{$version, $installDir, $macAddress}'
}
