#!/bin/sh

REMOTEIT_DIR="/var/packages/Remoteit/target/app"
ARCH_FAMILY=$(cat $REMOTEIT_DIR/arch_family)
ARCH_DIR=$REMOTEIT_DIR/arch/$ARCH_FAMILY

. $REMOTEIT_DIR/oem.sh

INSTALL_API=https://install.remote.it/v1


r3_update_config() {
  echo "Updating remote.it configuration."

  local config

  if [ -f $REMOTEIT_DIR/config.json ]; then
    config=$(cat $REMOTEIT_DIR/config.json)
  else
    config='{}'
  fi


  $ARCH_DIR/jq -n \
  --argjson config "$config" \
  --arg name "$(r3_get_name)" \
  --arg identity "$(r3_get_identity)" \
  --argjson manufacturer "$(r3_get_manufacturer)" \
  --argjson platform "$(r3_get_platform)" \
  --argjson metadata "$(r3_get_metadata)" \
  '$config * {$name, $identity, $manufacturer, $platform, $metadata}' | curl -sfo $REMOTEIT_DIR/config.json -d @- $INSTALL_API/refresh

}

r3_get_config() {
  [ -r $REMOTEIT_DIR/config.json ] || exit 0
  config=$($ARCH_DIR/jq -r --arg id "$1" '.device,.services[] | select(.id==$id) | .config' "$REMOTEIT_DIR/config.json")
  echo $config
}


r3_remove_agent() {
  echo "Removing remote.it agent."

  r3_stop_services

  #r3_remoteit_refresh_remove 

  #rm -f /etc/init.d/remoteit-refresh
  #rm -f /usr/bin/connectd_task_notify
  #rm -r /usr/share/remoteit
}

r3_reload_agent() {
  r3_update_config
  #r3_start_services 


  for id in $($ARCH_DIR/jq -r '.device,.services[] | .id' "$REMOTEIT_DIR/config.json"); do

    if [ -f /tmp/remoteit-$id.pid ]; then 
      pid=$(cat /tmp/remoteit-$id.pid )
      kill -15 $pid
    fi


    PIDFILE=/tmp/remoteit-$id.pid
    config=$($ARCH_DIR/jq -r --arg id "$id" '.device,.services[] | select(.id==$id) | .config' "$REMOTEIT_DIR/config.json")

    [ -n "$config" ] && exec "$ARCH_DIR/connectd" -d $PIDFILE -e "$config" &
  done
}


r3_reload_agent
