#!/bin/sh

REMOTEIT_DIR="$(readlink -f /var/packages/Remoteit/target)/app"

. $REMOTEIT_DIR/functions.sh
ARCH_FAMILY=$(cat $REMOTEIT_DIR/arch_family)
ARCH_DIR=$REMOTEIT_DIR/arch/$ARCH_FAMILY

parse_command() {
  local cmd=$1

  case $cmd in
  0)
    echo /bulk/job/task/update
    ;;
  1)
    echo /bulk/job/task/done
    ;;
  2)
    echo /bulk/job/task/failed
    ;;
  *[0-9])
    echo "/bulk/service/status/$(printf "\x$(printf %x $((cmd + 94)))")"
    ;;
  *)
    echo "/bulk/service/status/$cmd"
    ;;
  esac
}

cmd=$(parse_command "$1")
shift
task_id=$1
shift
api_base=${1:-api.remote.it/apv/v27}
shift
status=$(printf "%b" "$*")

output=$(mktemp /tmp/remoteit.XXXXXX)

code=$($ARCH_DIR/jq -n \
  --arg taskid "$task_id" \
  --arg description "$status" \
  '{$taskid, $description}' | curl -sfo "$output" -w "%{http_code}" -d @- "https://$api_base$cmd")

if [ "$code" -eq 200 ]; then
  echo "$code $($ARCH_DIR/jq -er '.status' "$output")"
else
  echo "$code $($ARCH_DIR/jq -er '.reason // "FAIL"' "$output")"
fi

rm -f "$output"
